summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:01:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:01:04 -0600
commit84c989c19db5daab602a67f47ca0f5fd7a2b53d2 (patch)
treedc5875bd392dce2d636a94bebcf5c44a270fac6d /lib
parent9445f97b426e97c6ce46de18fba4030da45d56df (diff)
downloadtdewebdev-84c989c19db5daab602a67f47ca0f5fd7a2b53d2.tar.gz
tdewebdev-84c989c19db5daab602a67f47ca0f5fd7a2b53d2.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'lib')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kdockwidget.cpp90
-rw-r--r--lib/compatibility/kmdi/qextmdi/kdockwidget.h4
-rw-r--r--lib/compatibility/kmdi/qextmdi/kdockwidget_p.h4
-rw-r--r--lib/compatibility/kmdi/qextmdi/kdockwidget_private.cpp16
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp8
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildarea.h4
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrm.cpp16
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrm.h6
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.cpp4
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildview.cpp34
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildview.h12
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidefines.h2
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidockcontainer.cpp24
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidocumentviewtabwidget.cpp6
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdiguiclient.cpp6
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp32
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdimainfrm.h4
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmultitabbar.cpp16
-rw-r--r--lib/compatibility/kmdi/qextmdi/ktabbar.cpp6
-rw-r--r--lib/compatibility/kmdi/qextmdi/ktabwidget.cpp2
-rw-r--r--lib/compatibility/knewstuff/downloaddialog.cpp34
-rw-r--r--lib/compatibility/knewstuff/engine.cpp6
-rw-r--r--lib/compatibility/knewstuff/knewstuff.cpp2
-rw-r--r--lib/compatibility/knewstuff/knewstuffgeneric.cpp2
-rw-r--r--lib/compatibility/knewstuff/knewstuffsecure.cpp6
-rw-r--r--lib/compatibility/knewstuff/security.cpp2
26 files changed, 174 insertions, 174 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kdockwidget.h b/lib/compatibility/kmdi/qextmdi/kdockwidget.h
index 34e5784e..3f522f39 100644
--- a/lib/compatibility/kmdi/qextmdi/kdockwidget.h
+++ b/lib/compatibility/kmdi/qextmdi/kdockwidget.h
@@ -946,7 +946,7 @@ public:
#ifndef NO_KDE2
/**
* Saves the current state of the dockmanager and of all controlled widgets.
- * State means here to save the tqgeometry, visibility, parents, internal object names, orientation,
+ * State means here to save the geometry, visibility, parents, internal object names, orientation,
* separator positions, dockwidget-group information, tab widget states (if it is a tab group) and
* last but not least some necessary things for recovering the dockmainwindow state.
*
@@ -1318,7 +1318,7 @@ public:
/**
* Constructs a dockmainwindow. It calls its base class constructor and does additional things concerning
* to the dock stuff:
- * @li information about the dock state of this' tqchildren gets initialized
+ * @li information about the dock state of this' children gets initialized
* @li a dockmanager is created...
* @li ...and gets initialized
* @li the main dockwidget is set to 0
diff --git a/lib/compatibility/kmdi/qextmdi/kdockwidget_p.h b/lib/compatibility/kmdi/qextmdi/kdockwidget_p.h
index 1ac686d9..9ee9e8e7 100644
--- a/lib/compatibility/kmdi/qextmdi/kdockwidget_p.h
+++ b/lib/compatibility/kmdi/qextmdi/kdockwidget_p.h
@@ -77,8 +77,8 @@ private:
- struct ListItem *m_tqchildrenListBegin;
- struct ListItem *m_tqchildrenListEnd;
+ struct ListItem *m_childrenListBegin;
+ struct ListItem *m_childrenListEnd;
class KDockContainerPrivate;
KDockContainerPrivate *d;
diff --git a/lib/compatibility/kmdi/qextmdi/kdockwidget_private.cpp b/lib/compatibility/kmdi/qextmdi/kdockwidget_private.cpp
index c2d2a1a8..49ddccdc 100644
--- a/lib/compatibility/kmdi/qextmdi/kdockwidget_private.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kdockwidget_private.cpp
@@ -423,7 +423,7 @@ bool KDockSplitter::eventFilter(TQObject *o, TQEvent *e)
} else {
xpos = factor * checkValue( mapFromGlobal(mev->globalPos()).y() ) / height();
resizeEvent(0);
- divider->tqrepaint(true);
+ divider->repaint(true);
}
} else {
if ((fixedWidth0!=-1) || (fixedWidth1!=-1))
@@ -436,7 +436,7 @@ bool KDockSplitter::eventFilter(TQObject *o, TQEvent *e)
} else {
xpos = factor * checkValue( mapFromGlobal( mev->globalPos()).x() ) / width();
resizeEvent(0);
- divider->tqrepaint(true);
+ divider->repaint(true);
}
}
handled= true;
@@ -452,7 +452,7 @@ bool KDockSplitter::eventFilter(TQObject *o, TQEvent *e)
}
xpos = factor* checkValue( mapFromGlobal(mev->globalPos()).y() ) / height();
resizeEvent(0);
- divider->tqrepaint(true);
+ divider->repaint(true);
} else {
if ((fixedWidth0!=-1) || (fixedWidth1!=-1))
{
@@ -460,7 +460,7 @@ bool KDockSplitter::eventFilter(TQObject *o, TQEvent *e)
}
xpos = factor* checkValue( mapFromGlobal(mev->globalPos()).x() ) / width();
resizeEvent(0);
- divider->tqrepaint(true);
+ divider->repaint(true);
}
handled= true;
break;
@@ -473,7 +473,7 @@ bool KDockSplitter::eventFilter(TQObject *o, TQEvent *e)
bool KDockSplitter::event( TQEvent* e )
{
if ( e->type() == TQEvent::LayoutHint ){
- // change tqchildren min/max size
+ // change children min/max size
setupMinMaxSize();
setSeparatorPos(xpos);
}
@@ -492,7 +492,7 @@ void KDockSplitter::updateName()
TQString new_name = TQString( child0->name() ) + "," + child1->name();
parentWidget()->setName( new_name.latin1() );
parentWidget()->setCaption( child0->caption() + "," + child1->caption() );
- parentWidget()->tqrepaint( false );
+ parentWidget()->repaint( false );
((KDockWidget*)parentWidget())->firstName = child0->name();
((KDockWidget*)parentWidget())->lastName = child1->name();
@@ -580,13 +580,13 @@ void KDockButton_Private::drawButton( TQPainter* p )
void KDockButton_Private::enterEvent( TQEvent * )
{
moveMouse = true;
- tqrepaint();
+ repaint();
}
void KDockButton_Private::leaveEvent( TQEvent * )
{
moveMouse = false;
- tqrepaint();
+ repaint();
}
/*************************************************************************/
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
index ae7c6bcd..19bd28fb 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildarea.cpp
@@ -181,7 +181,7 @@ void KMdiChildArea::setTopChild( KMdiChildFrm* child, bool /* bSetFocus */ )
m_pZ->removeRef( child );
m_pZ->setAutoDelete( true );
- //disable the labels of all the other tqchildren
+ //disable the labels of all the other children
TQPtrListIterator<KMdiChildFrm> it( *m_pZ );
for ( ; ( *it ); ++it )
( *it )->m_pCaption->setActive( false );
@@ -230,7 +230,7 @@ void KMdiChildArea::setTopChild( KMdiChildFrm* child, bool /* bSetFocus */ )
void KMdiChildArea::resizeEvent( TQResizeEvent* e )
{
- //If we have a maximized tqchildren at the top , adjust its size
+ //If we have a maximized children at the top , adjust its size
KMdiChildFrm* child = topChild();
if ( child && child->state() == KMdiChildFrm::Maximized )
{
@@ -368,7 +368,7 @@ void KMdiChildArea::focusTopChild()
if ( !lastChild->m_pClient->hasFocus() )
{
- //disable the labels of all the other tqchildren
+ //disable the labels of all the other children
TQPtrListIterator<KMdiChildFrm> it ( *m_pZ );
for ( ; ( *it ); ++it )
{
@@ -742,7 +742,7 @@ void KMdiChildArea::layoutMinimizedChildren()
}
child->move( posX, posY - child->height() );
- posX = child->tqgeometry().right();
+ posX = child->geometry().right();
}
}
}
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildarea.h b/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
index e175373e..546843a5 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
@@ -138,13 +138,13 @@ public:
void setTopChild( KMdiChildFrm* child, bool setFocus = false );
/**
- * Returns the topmost child (the active one) or 0 if there are no tqchildren.
+ * Returns the topmost child (the active one) or 0 if there are no children.
* Note that the topmost child may be also hidded , if ALL the windows are minimized.
*/
inline KMdiChildFrm * topChild() const { return m_pZ->last(); }
/**
- * Returns the number of visible tqchildren
+ * Returns the number of visible children
*/
int getVisibleChildCount() const;
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.cpp
index c9c8fa16..4a8fbdd6 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.cpp
@@ -590,7 +590,7 @@ void KMdiChildFrm::setState( MdiWindowState state, bool /*bAnimate*/ )
TQRect maximizedFrmRect( -m_pClient->x(), -m_pClient->y(),
m_pManager->width() + nFrameWidth,
m_pManager->height() + nFrameHeight );
- if ( tqgeometry() != maximizedFrmRect )
+ if ( geometry() != maximizedFrmRect )
{
setGeometry( maximizedFrmRect );
}
@@ -633,7 +633,7 @@ void KMdiChildFrm::setState( MdiWindowState state, bool /*bAnimate*/ )
{
m_oldLayoutResizeMode = m_pClient->tqlayout() ->resizeMode();
}
- m_restoredRect = tqgeometry();
+ m_restoredRect = geometry();
m_pClient->setMinimumSize( 0, 0 );
m_pClient->setMaximumSize( 0, 0 );
if ( m_pClient->tqlayout() != 0L )
@@ -694,7 +694,7 @@ void KMdiChildFrm::setCaption( const TQString& text )
void KMdiChildFrm::enableClose( bool bEnable )
{
m_pClose->setEnabled( bEnable );
- m_pClose->tqrepaint( false );
+ m_pClose->repaint( false );
}
//============ setIcon ==================//
@@ -1005,7 +1005,7 @@ void KMdiChildFrm::doResize( bool captionOnly )
TQWidget* pIconWidget = m_pWinIcon;
m_pCaption->setGeometry( KMDI_CHILDFRM_BORDER, KMDI_CHILDFRM_BORDER, captionWidth, captionHeight );
- //The buttons are caption tqchildren
+ //The buttons are caption children
if ( KMdiMainFrm::frameDecorOfAttachedViews() == KMdi::Win95Look )
{
rightOffset2 += 2;
@@ -1153,7 +1153,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
case TQEvent::ChildRemoved:
{
// if we lost a child we uninstall ourself as event filter for the lost
- // child and its tqchildren
+ // child and its children
TQObject* pLostChild = TQT_TQOBJECT(( ( TQChildEvent* ) e )->child());
if ( ( pLostChild != 0L ) /*&& (pLostChild->inherits(TQWIDGET_OBJECT_NAME_STRING))*/ )
{
@@ -1174,7 +1174,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
case TQEvent::ChildInserted:
{
// if we got a new child we install ourself as event filter for the new
- // child and its tqchildren (as we did when we got our client).
+ // child and its children (as we did when we got our client).
// XXX see linkChildren() and focus policy stuff
TQObject* pNewChild = TQT_TQOBJECT(( ( TQChildEvent* ) e ) ->child());
if ( ( pNewChild != 0L ) && ::tqqt_cast<TQWidget*>( pNewChild ) )
@@ -1284,9 +1284,9 @@ void KMdiChildFrm::showSystemMenu()
TQRect iconGeom;
if ( KMdiMainFrm::frameDecorOfAttachedViews() == KMdi::Win95Look )
- iconGeom = m_pWinIcon->tqgeometry();
+ iconGeom = m_pWinIcon->geometry();
else
- iconGeom = m_pUnixIcon->tqgeometry();
+ iconGeom = m_pUnixIcon->geometry();
popupmenuPosition = TQPoint( iconGeom.x(), iconGeom.y() + captionHeight() + KMDI_CHILDFRM_BORDER );
systemMenu() ->popup( mapToGlobal( popupmenuPosition ) );
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
index a63c4ed9..8257b883 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrm.h
@@ -247,12 +247,12 @@ public:
TQRect mdiAreaContentsRect() const;
/**
- * Returns the tqgeometry that will be restored by calling restore().
+ * Returns the geometry that will be restored by calling restore().
*/
TQRect restoreGeometry() const;
/**
- * Sets the tqgeometry that will be restored by calling restore().
+ * Sets the geometry that will be restored by calling restore().
*/
void setRestoreGeometry( const TQRect& newRestGeo );
@@ -354,7 +354,7 @@ protected:
virtual bool eventFilter( TQObject*, TQEvent* );
/**
- * Calculates the new tqgeometry from the new mouse position given as parameters
+ * Calculates the new geometry from the new mouse position given as parameters
* and calls KMdiChildFrm::setGeometry
*/
void resizeWindow( int resizeCorner, int x, int y );
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.cpp
index f243a2a7..ed4ba2d6 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.cpp
@@ -182,7 +182,7 @@ void KMdiChildFrmCaption::setActive( bool bActive )
m_pParent->m_pManager->m_captionInactiveBackColor );
m_bActive = bActive;
- tqrepaint( false );
+ repaint( false );
}
//=============== setCaption ===============//
@@ -190,7 +190,7 @@ void KMdiChildFrmCaption::setActive( bool bActive )
void KMdiChildFrmCaption::setCaption( const TQString& text )
{
m_szCaption = text;
- tqrepaint( false );
+ repaint( false );
}
//============== heightHint ===============//
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildview.h b/lib/compatibility/kmdi/qextmdi/kmdichildview.h
index f24e3195..9ce85fed 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildview.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildview.h
@@ -271,12 +271,12 @@ public:
bool isMaximized() const;
/**
- * Returns the tqgeometry of this MDI child window as TQWidget::tqgeometry() does.
+ * Returns the geometry of this MDI child window as TQWidget::geometry() does.
*/
TQRect internalGeometry() const;
/**
- * Sets the tqgeometry of the client area of this MDI child window. The
+ * Sets the geometry of the client area of this MDI child window. The
* top left position of the argument is the position of the top left point
* of the client area in its parent coordinates and the arguments width
* and height is the width and height of the client area. Please note: This
@@ -285,12 +285,12 @@ public:
void setInternalGeometry( const TQRect& newGeomety );
/**
- * Returns the frame tqgeometry of this window or of the parent if there is any...
+ * Returns the frame geometry of this window or of the parent if there is any...
*/
TQRect externalGeometry() const;
/**
- * Sets the tqgeometry of the frame of this MDI child window. The top left
+ * Sets the geometry of the frame of this MDI child window. The top left
* position of the argument is the position of the top left point of the
* frame in its parent coordinates and the arguments width and height is
* the width and height of the widget frame. Please note: This differs
@@ -316,12 +316,12 @@ public:
virtual void maximize( bool bAnimate );
/**
- * Returns the tqgeometry that will be restored by calling restore().
+ * Returns the geometry that will be restored by calling restore().
*/
TQRect restoreGeometry();
/**
- * Sets the tqgeometry that will be restored by calling restore().
+ * Sets the geometry that will be restored by calling restore().
*/
void setRestoreGeometry( const TQRect& newRestGeo );
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidefines.h b/lib/compatibility/kmdi/qextmdi/kmdidefines.h
index f8dfdeb2..ce41244a 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidefines.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdidefines.h
@@ -66,7 +66,7 @@ namespace KMdi
/**
* standard is: show normal, attached, visible, document view (not toolview). Maximize, Minimize, Hide adds
* appropriately. Detach adds a view that appears toplevel, ToolWindow adds the view as tool view.
- * That means it is stay-on-top and toplevel. UseKMdiSizeHint should use the restore tqgeometry of the
+ * That means it is stay-on-top and toplevel. UseKMdiSizeHint should use the restore geometry of the
* latest current top childframe but is not supported yet.
*/
StandardAdd = 0,
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.cpp b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.cpp
index b1d6d26c..d47b1cd4 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.cpp
@@ -514,7 +514,7 @@ void KMdiDockContainer::save( TQDomElement& dockEl )
TQDomDocument doc = dockEl.ownerDocument();
TQDomElement el;
el = doc.createElement( "name" );
- el.appendChild( doc.createTextNode( TQString( "%1" ).tqarg( parent() ->name() ) ) );
+ el.appendChild( doc.createTextNode( TQString( "%1" ).arg( parent() ->name() ) ) );
dockEl.appendChild( el );
el = doc.createElement( "overlapMode" );
el.appendChild( doc.createTextNode( isOverlapMode() ? "true" : "false" ) );
@@ -526,7 +526,7 @@ void KMdiDockContainer::save( TQDomElement& dockEl )
for ( ;it.current() != 0;++it, ++it2 )
{
el = doc.createElement( "child" );
- el.setAttribute( "pos", TQString( "%1" ).tqarg( i ) );
+ el.setAttribute( "pos", TQString( "%1" ).arg( i ) );
TQString s = tabCaptions[ *it2 ];
if ( !s.isEmpty() )
{
@@ -624,8 +624,8 @@ void KMdiDockContainer::load( TQDomElement& dockEl )
void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
{
TQString grp = cfg->group();
- cfg->deleteGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
- cfg->setGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
+ cfg->deleteGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
+ cfg->setGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
if ( isOverlapMode() )
cfg->writeEntry( "overlapMode", "true" );
@@ -647,17 +647,17 @@ void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
int i = 0;
for ( ;it.current() != 0;++it, ++it2 )
{
- // cfg->writeEntry(TQString("widget%1").tqarg(i),m_ws->widget(it.current()->id())->name());
- cfg->writeEntry( TQString( "widget%1" ).tqarg( i ), ( *it2 ) );
+ // cfg->writeEntry(TQString("widget%1").arg(i),m_ws->widget(it.current()->id())->name());
+ cfg->writeEntry( TQString( "widget%1" ).arg( i ), ( *it2 ) );
TQString s = tabCaptions[ *it2 ];
if ( !s.isEmpty() )
{
- cfg->writeEntry( TQString( "widget%1-tabCaption" ).tqarg( i ), s );
+ cfg->writeEntry( TQString( "widget%1-tabCaption" ).arg( i ), s );
}
s = tabTooltips[ *it2 ];
if ( !s.isEmpty() )
{
- cfg->writeEntry( TQString( "widget%1-tabTooltip" ).tqarg( i ), s );
+ cfg->writeEntry( TQString( "widget%1-tabTooltip" ).arg( i ), s );
}
// kdDebug(760)<<"****************************************Saving: "<<m_ws->widget(it.current()->id())->name()<<endl;
if ( m_tb->isTabRaised( it.current() ->id() ) )
@@ -672,7 +672,7 @@ void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
void KMdiDockContainer::load( KConfig* cfg, const TQString& group_or_prefix )
{
TQString grp = cfg->group();
- cfg->setGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
+ cfg->setGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
if ( cfg->readEntry( "overlapMode" ) != "false" )
activateOverlapMode( m_tb->width() );
@@ -685,19 +685,19 @@ void KMdiDockContainer::load( KConfig* cfg, const TQString& group_or_prefix )
TQString raise;
while ( true )
{
- TQString dwn = cfg->readEntry( TQString( "widget%1" ).tqarg( i ) );
+ TQString dwn = cfg->readEntry( TQString( "widget%1" ).arg( i ) );
if ( dwn.isEmpty() )
break;
kdDebug( 760 ) << k_funcinfo << "configuring dockwidget :" << dwn << endl;
KDockWidget *dw = ( ( KDockWidget* ) parent() ) ->dockManager() ->getDockWidgetFromName( dwn );
if ( dw )
{
- TQString s = cfg->readEntry( TQString( "widget%1-tabCaption" ).tqarg( i ) );
+ TQString s = cfg->readEntry( TQString( "widget%1-tabCaption" ).arg( i ) );
if ( !s.isEmpty() )
{
dw->setTabPageLabel( s );
}
- s = cfg->readEntry( TQString( "widget%1-tabTooltip" ).tqarg( i ) );
+ s = cfg->readEntry( TQString( "widget%1-tabTooltip" ).arg( i ) );
if ( !s.isEmpty() )
{
dw->setToolTipString( s );
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidocumentviewtabwidget.cpp b/lib/compatibility/kmdi/qextmdi/kmdidocumentviewtabwidget.cpp
index fb5ed357..f2c2d599 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidocumentviewtabwidget.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdidocumentviewtabwidget.cpp
@@ -56,7 +56,7 @@ void KMdiDocumentViewTabWidget::insertTab ( TQWidget * child, const TQString & l
KTabWidget::insertTab( child, label, index );
showPage( child );
maybeShow();
- tabBar() ->tqrepaint();
+ tabBar() ->repaint();
}
void KMdiDocumentViewTabWidget::insertTab ( TQWidget * child, const TQIconSet & iconset, const TQString & label, int index )
@@ -64,7 +64,7 @@ void KMdiDocumentViewTabWidget::insertTab ( TQWidget * child, const TQIconSet &
KTabWidget::insertTab( child, iconset, label, index );
showPage( child );
maybeShow();
- tabBar() ->tqrepaint();
+ tabBar() ->repaint();
}
void KMdiDocumentViewTabWidget::insertTab ( TQWidget * child, TQTab * tab, int index )
@@ -72,7 +72,7 @@ void KMdiDocumentViewTabWidget::insertTab ( TQWidget * child, TQTab * tab, int i
KTabWidget::insertTab( child, tab, index );
showPage( child );
maybeShow();
- tabBar() ->tqrepaint();
+ tabBar() ->repaint();
}
void KMdiDocumentViewTabWidget::removePage ( TQWidget * w )
diff --git a/lib/compatibility/kmdi/qextmdi/kmdiguiclient.cpp b/lib/compatibility/kmdi/qextmdi/kmdiguiclient.cpp
index 077f1e89..f27391c8 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdiguiclient.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdiguiclient.cpp
@@ -129,7 +129,7 @@ KMDIGUIClient::KMDIGUIClient( KMdiMainFrm* mdiMainFrm, bool showMDIModeAction, c
{
TQString completeDescription = TQString::fromLatin1( guiDescription )
- .tqarg( actionListName );
+ .arg( actionListName );
setXML( completeDescription, false /*merge*/ );
}
@@ -257,12 +257,12 @@ void KMDIGUIClient::addToolView( KMdiToolViewAccessor* mtva )
// if ( cfg->hasKey( aname ) )
sc = KShortcut( cfg->readEntry( aname, "" ) );
cfg->setGroup( _grp );
- KAction *a = new ToggleToolViewAction( i18n( "Show %1" ).tqarg( mtva->wrappedWidget() ->caption() ),
+ KAction *a = new ToggleToolViewAction( i18n( "Show %1" ).arg( mtva->wrappedWidget() ->caption() ),
/*TQString()*/sc, dynamic_cast<KDockWidget*>( mtva->wrapperWidget() ),
m_mdiMainFrm, actionCollection(), aname.latin1() );
#if KDE_IS_VERSION(3,2,90)
- ( ( ToggleToolViewAction* ) a ) ->setCheckedState( i18n( "Hide %1" ).tqarg( mtva->wrappedWidget() ->caption() ) );
+ ( ( ToggleToolViewAction* ) a ) ->setCheckedState( i18n( "Hide %1" ).arg( mtva->wrappedWidget() ->caption() ) );
#endif
connect( a, TQT_SIGNAL( destroyed( TQObject* ) ), this, TQT_SLOT( actionDeleted( TQObject* ) ) );
diff --git a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
index 18a47c3a..ea19c899 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
@@ -142,7 +142,7 @@ public:
* use fakeSDIApplication() to fake it and isFakingSDIApplication() to query whether or not an SDI
* interface is being faked.
*
- * You can dynamically change the tqshape of the attached MDI views using setFrameDecorOfAttachedViews().
+ * You can dynamically change the shape of the attached MDI views using setFrameDecorOfAttachedViews().
*
* Additionally, here's a hint how to restore the mainframe's settings from config file:
* \code
@@ -526,7 +526,7 @@ public slots:
/**
* Adds a KMdiChildView to the MDI system. The main frame takes control of it.
- * \param rectNormal Sets the tqgeometry for this child view
+ * \param rectNormal Sets the geometry for this child view
* \param flags the flags for the view such as:
* \li whether the view should be attached or detached.
* \li whether the view should be shown or hidden
diff --git a/lib/compatibility/kmdi/qextmdi/kmultitabbar.cpp b/lib/compatibility/kmdi/qextmdi/kmultitabbar.cpp
index aee5b47c..72b244fe 100644
--- a/lib/compatibility/kmdi/qextmdi/kmultitabbar.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmultitabbar.cpp
@@ -110,7 +110,7 @@ void KMultiTabBarInternal::setStyle(enum KMultiTabBar::KMultiTabBarStyle style)
mainLayout->setAutoAdd(true);
}
- viewport()->tqrepaint();
+ viewport()->repaint();
}
void KMultiTabBarInternal::drawContents ( TQPainter * paint, int clipx, int clipy, int clipw, int cliph )
@@ -188,8 +188,8 @@ void KMultiTabBarInternal::mousePressEvent(TQMouseEvent *ev)
void KMultiTabBarInternal::resizeEvent(TQResizeEvent *ev) {
/* kdDebug()<<"KMultiTabBarInternal::resizeEvent"<<endl;
- kdDebug()<<"KMultiTabBarInternal::resizeEvent - box tqgeometry"<<box->tqgeometry()<<endl;
- kdDebug()<<"KMultiTabBarInternal::resizeEvent - tqgeometry"<<tqgeometry()<<endl;*/
+ kdDebug()<<"KMultiTabBarInternal::resizeEvent - box geometry"<<box->geometry()<<endl;
+ kdDebug()<<"KMultiTabBarInternal::resizeEvent - geometry"<<geometry()<<endl;*/
if (ev) TQScrollView::resizeEvent(ev);
if ( (m_style==KMultiTabBar::KDEV3) ||
@@ -378,7 +378,7 @@ void KMultiTabBarInternal::setPosition(enum KMultiTabBar::KMultiTabBarPosition p
m_position=pos;
for (uint i=0;i<m_tabs.count();i++)
m_tabs.at(i)->setTabsPosition(m_position);
- viewport()->tqrepaint();
+ viewport()->repaint();
}
@@ -435,13 +435,13 @@ void KMultiTabBarButton::slotClicked()
void KMultiTabBarButton::setPosition(KMultiTabBar::KMultiTabBarPosition pos)
{
m_position=pos;
- tqrepaint();
+ repaint();
}
void KMultiTabBarButton::setStyle(KMultiTabBar::KMultiTabBarStyle style)
{
m_style=style;
- tqrepaint();
+ repaint();
}
void KMultiTabBarButton::hideEvent( TQHideEvent* he) {
@@ -526,7 +526,7 @@ void KMultiTabBarTab::setTabsPosition(KMultiTabBar::KMultiTabBarPosition pos)
}
setPosition(pos);
-// tqrepaint();
+// repaint();
}
void KMultiTabBarTab::setIcon(const TQString& icon)
@@ -980,7 +980,7 @@ void KMultiTabBar::fontChange(const TQFont& /* oldFont */)
{
for (uint i=0;i<tabs()->count();i++)
tabs()->at(i)->resize();
- tqrepaint();
+ repaint();
}
TQPtrList<KMultiTabBarTab>* KMultiTabBar::tabs() {return m_internal->tabs();}
diff --git a/lib/compatibility/kmdi/qextmdi/ktabbar.cpp b/lib/compatibility/kmdi/qextmdi/ktabbar.cpp
index 4b112f71..045b8a45 100644
--- a/lib/compatibility/kmdi/qextmdi/ktabbar.cpp
+++ b/lib/compatibility/kmdi/qextmdi/ktabbar.cpp
@@ -80,7 +80,7 @@ void KTabBar::setTabEnabled( int id, bool enabled )
emit selected( t->identifier() );
}
}
- tqrepaint( r );
+ repaint( r );
}
}
}
@@ -252,7 +252,7 @@ void KTabBar::dragMoveEvent( TQDragMoveEvent *e )
TQTab *tab = selectTab( e->pos() );
if( tab ) {
bool accept = false;
- // The tqreceivers of the testCanDecode() signal has to adjust
+ // The receivers of the testCanDecode() signal has to adjust
// 'accept' accordingly.
emit testCanDecode( e, accept);
if ( accept && tab != TQTabBar::tab( currentTab() ) ) {
@@ -293,7 +293,7 @@ void KTabBar::setTabColor( int id, const TQColor& color )
TQTab *t = tab( id );
if ( t ) {
mTabColors.insert( id, color );
- tqrepaint( t->rect(), false );
+ repaint( t->rect(), false );
}
}
diff --git a/lib/compatibility/kmdi/qextmdi/ktabwidget.cpp b/lib/compatibility/kmdi/qextmdi/ktabwidget.cpp
index 9453c182..8d74ebe3 100644
--- a/lib/compatibility/kmdi/qextmdi/ktabwidget.cpp
+++ b/lib/compatibility/kmdi/qextmdi/ktabwidget.cpp
@@ -294,7 +294,7 @@ void KTabWidget::dragMoveEvent( TQDragMoveEvent *e )
{
if ( isEmptyTabbarSpace( e->pos() ) ) {
bool accept = false;
- // The tqreceivers of the testCanDecode() signal has to adjust
+ // The receivers of the testCanDecode() signal has to adjust
// 'accept' accordingly.
emit testCanDecode( e, accept);
e->accept( accept );
diff --git a/lib/compatibility/knewstuff/downloaddialog.cpp b/lib/compatibility/knewstuff/downloaddialog.cpp
index c548f400..f1942f7f 100644
--- a/lib/compatibility/knewstuff/downloaddialog.cpp
+++ b/lib/compatibility/knewstuff/downloaddialog.cpp
@@ -364,9 +364,9 @@ void DownloadDialog::addEntry(Entry *entry)
else pix = TQPixmap();
KListViewItem *tmp_r = new KListViewItem(lv_r,
- entry->name(), entry->version(), TQString("%1").tqarg(entry->rating()));
+ entry->name(), entry->version(), TQString("%1").arg(entry->rating()));
KListViewItem *tmp_d = new NumSortListViewItem(lv_d,
- entry->name(), entry->version(), TQString("%1").tqarg(entry->downloads()));
+ entry->name(), entry->version(), TQString("%1").arg(entry->downloads()));
KListViewItem *tmp_l = new KListViewItem(lv_l,
entry->name(), entry->version(), KGlobal::locale()->formatDate(entry->releaseDate()));
@@ -403,23 +403,23 @@ void DownloadDialog::slotDetails()
"Downloads: %7\n"
"Release date: %8\n"
"Summary: %9\n"
- ).tqarg(e->name()
- ).tqarg(e->author()
- ).tqarg(e->license()
- ).tqarg(e->version()
- ).tqarg(e->release()
- ).tqarg(e->rating()
- ).tqarg(e->downloads()
- ).tqarg(KGlobal::locale()->formatDate(e->releaseDate())
- ).tqarg(e->summary(lang)
+ ).arg(e->name()
+ ).arg(e->author()
+ ).arg(e->license()
+ ).arg(e->version()
+ ).arg(e->release()
+ ).arg(e->rating()
+ ).arg(e->downloads()
+ ).arg(KGlobal::locale()->formatDate(e->releaseDate())
+ ).arg(e->summary(lang)
);
info.append(i18n
(
"Preview: %1\n"
"Payload: %2\n"
- ).tqarg(e->preview().url()
- ).tqarg(e->payload().url()
+ ).arg(e->preview().url()
+ ).arg(e->payload().url()
));
KMessageBox::information(this, info, i18n("Details"));
@@ -514,14 +514,14 @@ void DownloadDialog::slotSelected()
{
if(!e->preview(lang).isValid())
{
- m_rt->setText(TQString("<b>%1</b><br>%2<br>%3<br><br><i>%4</i><br>(%5)").tqarg(
- e->name()).tqarg(e->author()).tqarg(KGlobal::locale()->formatDate(e->releaseDate())).tqarg(e->summary(lang)).tqarg(e->license()));
+ m_rt->setText(TQString("<b>%1</b><br>%2<br>%3<br><br><i>%4</i><br>(%5)").arg(
+ e->name()).arg(e->author()).arg(KGlobal::locale()->formatDate(e->releaseDate())).arg(e->summary(lang)).arg(e->license()));
}
else
{
KIO::NetAccess::download(e->preview(lang), tmp, this);
- m_rt->setText(TQString("<b>%1</b><br>%2<br>%3<br><br><img src='%4'><br><i>%5</i><br>(%6)").tqarg(
- e->name()).tqarg(e->author()).tqarg(KGlobal::locale()->formatDate(e->releaseDate())).tqarg(tmp).tqarg(e->summary(lang)).tqarg(e->license()));
+ m_rt->setText(TQString("<b>%1</b><br>%2<br>%3<br><br><img src='%4'><br><i>%5</i><br>(%6)").arg(
+ e->name()).arg(e->author()).arg(KGlobal::locale()->formatDate(e->releaseDate())).arg(tmp).arg(e->summary(lang)).arg(e->license()));
}
if(installStatus(e) == 1) enabled = false;
diff --git a/lib/compatibility/knewstuff/engine.cpp b/lib/compatibility/knewstuff/engine.cpp
index e15b27c6..ca63ea98 100644
--- a/lib/compatibility/knewstuff/engine.cpp
+++ b/lib/compatibility/knewstuff/engine.cpp
@@ -283,11 +283,11 @@ void Engine::upload( Entry *entry )
}
TQString text = i18n("The files to be uploaded have been created at:\n");
- text.append( i18n("Data file: %1\n").tqarg( mUploadFile) );
+ text.append( i18n("Data file: %1\n").arg( mUploadFile) );
if (!mPreviewFile.isEmpty()) {
- text.append( i18n("Preview image: %1\n").tqarg( mPreviewFile) );
+ text.append( i18n("Preview image: %1\n").arg( mPreviewFile) );
}
- text.append( i18n("Content information: %1\n").tqarg( mUploadMetaFile) );
+ text.append( i18n("Content information: %1\n").arg( mUploadMetaFile) );
text.append( i18n("Those files can now be uploaded.\n") );
text.append( i18n("Beware that any people might have access to them at any time.") );
diff --git a/lib/compatibility/knewstuff/knewstuff.cpp b/lib/compatibility/knewstuff/knewstuff.cpp
index 7fa15372..6a37aa61 100644
--- a/lib/compatibility/knewstuff/knewstuff.cpp
+++ b/lib/compatibility/knewstuff/knewstuff.cpp
@@ -35,7 +35,7 @@ KAction* KNS::standardAction(const TQString& what,
const char *slot, KActionCollection* parent,
const char *name)
{
- return new KAction(i18n("Download New %1").tqarg(what), "knewstuff",
+ return new KAction(i18n("Download New %1").arg(what), "knewstuff",
0, recvr, slot, parent, name);
}
diff --git a/lib/compatibility/knewstuff/knewstuffgeneric.cpp b/lib/compatibility/knewstuff/knewstuffgeneric.cpp
index c7b4b855..fb3e788a 100644
--- a/lib/compatibility/knewstuff/knewstuffgeneric.cpp
+++ b/lib/compatibility/knewstuff/knewstuffgeneric.cpp
@@ -131,7 +131,7 @@ TQString KNewStuffGeneric::downloadDestination( KNS::Entry *entry )
if ( KStandardDirs::exists( file ) ) {
int result = KMessageBox::warningContinueCancel( parentWidget(),
i18n("The file '%1' already exists. Do you want to override it?")
- .tqarg( file ),
+ .arg( file ),
TQString(), i18n("Overwrite") );
if ( result == KMessageBox::Cancel ) return TQString();
}
diff --git a/lib/compatibility/knewstuff/knewstuffsecure.cpp b/lib/compatibility/knewstuff/knewstuffsecure.cpp
index d9bf82af..7b98dbba 100644
--- a/lib/compatibility/knewstuff/knewstuffsecure.cpp
+++ b/lib/compatibility/knewstuff/knewstuffsecure.cpp
@@ -128,16 +128,16 @@ void KNewStuffSecure::slotValidated(int result)
valid = false;
} else
{
- signatureStr = i18n("The resource was signed with key <i>0x%1</i>, belonging to <i>%2 &lt;%3&gt;</i>.").tqarg(key.id.right(8)).tqarg(key.name).tqarg(key.mail);
+ signatureStr = i18n("The resource was signed with key <i>0x%1</i>, belonging to <i>%2 &lt;%3&gt;</i>.").arg(key.id.right(8)).arg(key.name).arg(key.mail);
}
}
if (!valid)
{
signatureStr.prepend( "<br>");
- if (KMessageBox::warningContinueCancel(parentWidget(), i18n("<qt>There is a problem with the resource file you have downloaded. The errors are :<b>%1</b><br>%2<br><br>Installation of the resource is <b>not recommended</b>.<br><br>Do you want to proceed with the installation?</qt>").tqarg(errorString).tqarg(signatureStr), i18n("Problematic Resource File")) == KMessageBox::Continue)
+ if (KMessageBox::warningContinueCancel(parentWidget(), i18n("<qt>There is a problem with the resource file you have downloaded. The errors are :<b>%1</b><br>%2<br><br>Installation of the resource is <b>not recommended</b>.<br><br>Do you want to proceed with the installation?</qt>").arg(errorString).arg(signatureStr), i18n("Problematic Resource File")) == KMessageBox::Continue)
valid = true;
} else
- KMessageBox::information(parentWidget(), i18n("<qt>%1<br><br>Press OK to install it.</qt>").tqarg(signatureStr), i18n("Valid Resource"), "Show Valid Signature Information");
+ KMessageBox::information(parentWidget(), i18n("<qt>%1<br><br>Press OK to install it.</qt>").arg(signatureStr), i18n("Valid Resource"), "Show Valid Signature Information");
if (valid)
{
installResource();
diff --git a/lib/compatibility/knewstuff/security.cpp b/lib/compatibility/knewstuff/security.cpp
index 9dc5615a..8ef377b7 100644
--- a/lib/compatibility/knewstuff/security.cpp
+++ b/lib/compatibility/knewstuff/security.cpp
@@ -174,7 +174,7 @@ void Security::slotDataArrived(KProcIO *procIO)
{
TQCString password;
KeyStruct key = m_keys[m_secretKey];
- int result = KPasswordDialog::getPassword(password, i18n("<qt>Enter passphrase for key <b>0x%1</b>, belonging to<br><i>%2&lt;%3&gt;</i>:</qt>").tqarg(m_secretKey).tqarg(key.name).tqarg(key.mail));
+ int result = KPasswordDialog::getPassword(password, i18n("<qt>Enter passphrase for key <b>0x%1</b>, belonging to<br><i>%2&lt;%3&gt;</i>:</qt>").arg(m_secretKey).arg(key.name).arg(key.mail));
if (result == KPasswordDialog::Accepted)
{
procIO->writeStdin(password, true);
diff --git a/lib/compatibility/kmdi/qextmdi/kdockwidget.cpp b/lib/compatibility/kmdi/qextmdi/kdockwidget.cpp
index df4b1ef8..323e7a06 100644
--- a/lib/compatibility/kmdi/qextmdi/kdockwidget.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kdockwidget.cpp
@@ -234,7 +234,7 @@ KDockWidgetHeader::KDockWidgetHeader( KDockWidget* parent, const char* name )
connect( closeButton, TQT_SIGNAL(clicked()), parent, TQT_SLOT(undock()));
stayButton = new KDockButton_Private( this, "DockStayButton" );
- TQToolTip::add( stayButton, i18n("Freeze the window tqgeometry", "Freeze") );
+ TQToolTip::add( stayButton, i18n("Freeze the window geometry", "Freeze") );
stayButton->setToggleButton( true );
stayButton->setPixmap( const_cast< const char** >(not_close_xpm) );
stayButton->setFixedSize(closeButton->pixmap()->width(),closeButton->pixmap()->height());
@@ -425,12 +425,12 @@ void KDockWidgetHeader::setDragEnabled(bool b)
#ifndef NO_KDE2
void KDockWidgetHeader::saveConfig( KConfig* c )
{
- c->writeEntry( TQString("%1%2").tqarg(parent()->name()).tqarg(":stayButton"), stayButton->isOn() );
+ c->writeEntry( TQString("%1%2").arg(parent()->name()).arg(":stayButton"), stayButton->isOn() );
}
void KDockWidgetHeader::loadConfig( KConfig* c )
{
- setDragEnabled( !c->readBoolEntry( TQString("%1%2").tqarg(parent()->name()).tqarg(":stayButton"), false ) );
+ setDragEnabled( !c->readBoolEntry( TQString("%1%2").arg(parent()->name()).arg(":stayButton"), false ) );
}
#endif
@@ -811,7 +811,7 @@ void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
}
if ( manager && s == manager->main ){
- setGeometry( TQRect(TQPoint(0,0), manager->main->tqgeometry().size()) );
+ setGeometry( TQRect(TQPoint(0,0), manager->main->geometry().size()) );
}
if ( !s )
@@ -1089,7 +1089,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
if ( !parentDock ){
// dock to a toplevel dockwidget means newDock is toplevel now
newDock->move( target->frameGeometry().topLeft() );
- newDock->resize( target->tqgeometry().size() );
+ newDock->resize( target->geometry().size() );
if ( target->isVisibleToTLW() ) newDock->show();
}
@@ -1124,7 +1124,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
tab->insertTab( this, icon() ? *icon() : TQPixmap(),
tabPageLabel(), tabIndex );
- TQRect geom=newDock->tqgeometry();
+ TQRect geom=newDock->geometry();
TQWidget *wantTransient=tab->transientTo();
newDock->setDockWindowTransient(wantTransient,wantTransient);
newDock->setGeometry(geom);
@@ -1478,7 +1478,7 @@ void KDockWidget::setDockTabName( KDockTabGroup* tab )
tab->parentWidget()->setName( listOfName.utf8() );
tab->parentWidget()->setCaption( listOfCaption );
- tab->parentWidget()->tqrepaint( false ); // KDockWidget->tqrepaint
+ tab->parentWidget()->repaint( false ); // KDockWidget->repaint
if ( tab->parentWidget()->parent() )
if ( tab->parentWidget()->parent()->inherits("KDockSplitter") )
((KDockSplitter*)(tab->parentWidget()->parent()))->updateName();
@@ -1551,13 +1551,13 @@ void KDockWidget::loseFormerBrotherDockWidget()
TQObject::disconnect( formerBrotherDockWidget, TQT_SIGNAL(iMBeingClosed()),
this, TQT_SLOT(loseFormerBrotherDockWidget()) );
formerBrotherDockWidget = 0L;
- tqrepaint();
+ repaint();
}
void KDockWidget::dockBack()
{
if( formerBrotherDockWidget) {
// search all tqchildren if it tries to dock back to a child
bool found = false;
TQObjectList* cl = queryList("KDockWidget");
TQObjectListIt it( *cl );
@@ -1713,7 +1713,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
findChildDockWidget( curdw, childDockWidgetList );
//d->oldDragRect = TQRect(); should fix rectangle not erased problem
- d->dragRect = TQRect(curdw->tqgeometry());
+ d->dragRect = TQRect(curdw->geometry());
TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
d->dragRect.moveTopLeft(p);
drawDragRectangle();
@@ -1735,7 +1735,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
if (d->readyToDrag) {
d->readyToDrag = false;
//d->oldDragRect = TQRect(); should fix rectangle not erased problem
- d->dragRect = TQRect(curdw->tqgeometry());
+ d->dragRect = TQRect(curdw->geometry());
TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
d->dragRect.moveTopLeft(p);
drawDragRectangle();
@@ -1775,7 +1775,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
break;
} else {
if (dropCancel && curdw) {
- d->dragRect = TQRect(curdw->tqgeometry());
+ d->dragRect = TQRect(curdw->geometry());
TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
d->dragRect.moveTopLeft(p);
}else
@@ -1892,7 +1892,7 @@ void KDockManager::findChildDockWidget( TQWidget*& ww, const TQWidget* p, const
while ( it.current() ) {
if ( it.current()->isWidgetType() ) {
w = (TQWidget*)it.current();
- if ( w->isVisible() && w->tqgeometry().contains(pos) ) {
+ if ( w->isVisible() && w->geometry().contains(pos) ) {
if ( w->inherits("KDockWidget") ) ww = w;
findChildDockWidget( ww, w, w->mapFromParent(pos) );
return;
@@ -2178,7 +2178,7 @@ void KDockManager::writeConfig(TQDomElement &base)
KDockWidget *obj = getDockWidgetFromName( *nListIt);
if ((obj->isGroup && (!obj->d->isContainer)) && (nameList.find( obj->firstName.latin1() ) == -1
|| nameList.find(obj->lastName.latin1()) == -1)) {
- // Skip until tqchildren are saved (why?)
+ // Skip until children are saved (why?)
++nListIt;
// nList.next();
//falk? if ( !nList.current() ) nList.first();
@@ -2498,7 +2498,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
c->writeEntry( "Main:view", obj->name() );
}
-// kdDebug(282)<<TQString("list size: %1").tqarg(nList.count())<<endl;
+// kdDebug(282)<<TQString("list size: %1").arg(nList.count())<<endl;
for (TQObjectListIt it(d->containerDocks);it.current();++it)
{
KDockContainer* dc = dynamic_cast<KDockContainer*>(((KDockWidget*)it.current())->widget);
@@ -2506,7 +2506,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
dc->prepareSave(nList);
}
}
-// kdDebug(282)<<TQString("new list size: %1").tqarg(nList.count())<<endl;
+// kdDebug(282)<<TQString("new list size: %1").arg(nList.count())<<endl;
TQStringList::Iterator nListIt=nList.begin();
while ( nListIt!=nList.end() ){
@@ -2529,7 +2529,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
c->writeEntry( cname+":type", "GROUP");
if ( !obj->parent() ){
c->writeEntry( cname+":parent", "___null___");
- c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+ c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
c->writeEntry( cname+":visible", obj->isVisible());
} else {
c->writeEntry( cname+":parent", "yes");
@@ -2561,7 +2561,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
c->writeEntry( cname+":type", "TAB_GROUP");
if ( !obj->parent() ){
c->writeEntry( cname+":parent", "___null___");
- c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+ c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
c->writeEntry( cname+":visible", obj->isVisible());
c->writeEntry( cname+":dockBackTo", obj->formerBrotherDockWidget ? obj->formerBrotherDockWidget->name() : "");
c->writeEntry( cname+":dockBackToPos", obj->formerDockPos);
@@ -2585,7 +2585,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
c->writeEntry( cname+":tabToolTip", obj->toolTipString());
if ( !obj->parent() ){
c->writeEntry( cname+":type", "NULL_DOCK");
- c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+ c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
c->writeEntry( cname+":visible", obj->isVisible());
c->writeEntry( cname+":dockBackTo", obj->formerBrotherDockWidget ? obj->formerBrotherDockWidget->name() : "");
c->writeEntry( cname+":dockBackToPos", obj->formerDockPos);
@@ -2660,7 +2660,7 @@ void KDockManager::readConfig( KConfig* c, TQString group )
obj = 0L;
if ( type == "NULL_DOCK" || c->readEntry( oname + ":parent") == "___null___" ){
- TQRect r = c->readRectEntry( oname + ":tqgeometry" );
+ TQRect r = c->readRectEntry( oname + ":geometry" );
obj = getDockWidgetFromName( oname );
obj->applyToWidget( 0L );
obj->setGeometry(r);
@@ -2877,13 +2877,13 @@ void KDockManager::slotMenuPopup()
++it;
if ( obj->mayBeHide() )
{
- menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Hide %1").tqarg(obj->caption()), numerator++ );
+ menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Hide %1").arg(obj->caption()), numerator++ );
menuData->append( new MenuDockData( obj, true ) );
}
if ( obj->mayBeShow() )
{
- menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Show %1").tqarg(obj->caption()), numerator++ );
+ menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Show %1").arg(obj->caption()), numerator++ );
menuData->append( new MenuDockData( obj, false ) );
}
}
@@ -3059,11 +3059,11 @@ void KDockArea::resizeEvent(TQResizeEvent *rsize)
delete list;
#if 0
KDockSplitter *split;
-// for (unsigned int i=0;i<tqchildren()->count();i++)
+// for (unsigned int i=0;i<children()->count();i++)
{
-// TQPtrList<TQObject> list(tqchildren());
-// TQObject *obj=((TQPtrList<TQObject*>)tqchildren())->at(i);
- TQObject *obj=tqchildren()->getFirst();
+// TQPtrList<TQObject> list(children());
+// TQObject *obj=((TQPtrList<TQObject*>)children())->at(i);
+ TQObject *obj=children()->getFirst();
if (split = dynamic_cast<KDockSplitter*>(obj))
{
split->setGeometry( TQRect(TQPoint(0,0), size() ));
@@ -3096,12 +3096,12 @@ void KDockArea::setMainDockWidget( KDockWidget* mdw )
// KDOCKCONTAINER - AN ABSTRACTION OF THE KDOCKTABWIDGET
-KDockContainer::KDockContainer(){m_overlapMode=false; m_tqchildrenListBegin=0; m_tqchildrenListEnd=0;}
+KDockContainer::KDockContainer(){m_overlapMode=false; m_childrenListBegin=0; m_childrenListEnd=0;}
KDockContainer::~KDockContainer(){
- if (m_tqchildrenListBegin)
+ if (m_childrenListBegin)
{
- struct ListItem *tmp=m_tqchildrenListBegin;
+ struct ListItem *tmp=m_childrenListBegin;
while (tmp)
{
struct ListItem *tmp2=tmp->next;
@@ -3109,8 +3109,8 @@ KDockContainer::~KDockContainer(){
delete tmp;
tmp=tmp2;
}
- m_tqchildrenListBegin=0;
- m_tqchildrenListEnd=0;
+ m_childrenListBegin=0;
+ m_childrenListEnd=0;
}
}
@@ -3156,7 +3156,7 @@ KDockWidget *KDockContainer::parentDockWidget(){return 0;}
TQStringList KDockContainer::containedWidgets() const {
TQStringList tmp;
- for (struct ListItem *it=m_tqchildrenListBegin;it;it=it->next) {
+ for (struct ListItem *it=m_childrenListBegin;it;it=it->next) {
tmp<<TQString(it->data);
}
@@ -3172,36 +3172,36 @@ void KDockContainer::insertWidget (KDockWidget *dw, TQPixmap, const TQString &,
it->data=strdup(dw->name());
it->next=0;
- if (m_tqchildrenListEnd)
+ if (m_childrenListEnd)
{
- m_tqchildrenListEnd->next=it;
- it->prev=m_tqchildrenListEnd;
- m_tqchildrenListEnd=it;
+ m_childrenListEnd->next=it;
+ it->prev=m_childrenListEnd;
+ m_childrenListEnd=it;
}
else
{
it->prev=0;
- m_tqchildrenListEnd=it;
- m_tqchildrenListBegin=it;
+ m_childrenListEnd=it;
+ m_childrenListBegin=it;
}
}
void KDockContainer::removeWidget (KDockWidget *dw){
- for (struct ListItem *tmp=m_tqchildrenListBegin;tmp;tmp=tmp->next)
+ for (struct ListItem *tmp=m_childrenListBegin;tmp;tmp=tmp->next)
{
if (!strcmp(tmp->data,dw->name()))
{
free(tmp->data);
if (tmp->next) tmp->next->prev=tmp->prev;
if (tmp->prev) tmp->prev->next=tmp->next;
- if (tmp==m_tqchildrenListBegin) m_tqchildrenListBegin=tmp->next;
- if (tmp==m_tqchildrenListEnd) m_tqchildrenListEnd=tmp->prev;
+ if (tmp==m_childrenListBegin) m_childrenListBegin=tmp->next;
+ if (tmp==m_childrenListEnd) m_childrenListEnd=tmp->prev;
delete tmp;
break;
}
}
}
-//m_tqchildren.remove(dw->name());}
+//m_children.remove(dw->name());}
void KDockContainer::undockWidget (KDockWidget *){;}
void KDockContainer::setToolTip(KDockWidget *, TQString &){;}
void KDockContainer::setPixmap(KDockWidget*,const TQPixmap&){;}
@@ -3212,11 +3212,11 @@ void KDockContainer::save (TQDomElement&){;}
void KDockContainer::prepareSave(TQStringList &names)
{
- for (struct ListItem *tmp=m_tqchildrenListBegin;tmp; tmp=tmp->next)
+ for (struct ListItem *tmp=m_childrenListBegin;tmp; tmp=tmp->next)
names.remove(tmp->data);
-// for (uint i=0;i<m_tqchildren.count();i++)
+// for (uint i=0;i<m_children.count();i++)
// {
-// names.remove(m_tqchildren.at(i));
+// names.remove(m_children.at(i));
// }
}
@@ -1551,13 +1551,13 @@ void KDockWidget::loseFormerBrotherDockWidget()
{
if( formerBrotherDockWidget) {
- // search all tqchildren if it tries to dock back to a child
+ // search all children if it tries to dock back to a child
bool found = false;
TQObjectList* cl = queryList("KDockWidget");
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
index 93dcbb56..8afdf249 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
@@ -107,14 +107,14 @@ void KMdiChildView::trackIconAndCaptionChanges( TQWidget *view )
}
-//============== internal tqgeometry ==============//
+//============== internal geometry ==============//
TQRect KMdiChildView::internalGeometry() const
{
if ( mdiParent() )
{ // is attached
// get the client area coordinates inside the MDI child frame
- TQRect posInFrame = tqgeometry();
+ TQRect posInFrame = geometry();
// map these values to the parent of the MDI child frame
// (this usually is the MDI child area) and return
TQPoint ptTopLeft = mdiParent() ->mapToParent( posInFrame.topLeft() );
@@ -123,14 +123,14 @@ TQRect KMdiChildView::internalGeometry() const
}
else
{
- TQRect geo = tqgeometry();
+ TQRect geo = geometry();
TQRect frameGeo = externalGeometry();
return TQRect( frameGeo.x(), frameGeo.y(), geo.width(), geo.height() );
- // return tqgeometry();
+ // return geometry();
}
}
//============== set internal tqgeometry ==============//
void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
{
@@ -142,7 +142,7 @@ void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
int nFrameSizeTop = geo.y() - frameGeo.y();
int nFrameSizeLeft = geo.x() - frameGeo.x();
- // create the new tqgeometry that is accepted by the TQWidget::setGeometry() method
+ // create the new geometry that is accepted by the TQWidget::setGeometry() method
TQRect newGeoTQt;
newGeoTQt.setX( newGeometry.x() - nFrameSizeLeft );
newGeoTQt.setY( newGeometry.y() - nFrameSizeTop );
@@ -152,7 +152,7 @@ void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
// newGeoTQt.setWidth(newGeometry.width()+KMDI_MDI_CHILDFRM_DOUBLE_BORDER);
// newGeoTQt.setHeight(newGeometry.height()+mdiParent()->captionHeight()+KMDI_MDI_CHILDFRM_DOUBLE_BORDER);
- // set the tqgeometry
+ // set the geometry
mdiParent()->setGeometry( newGeoTQt );
}
else
@@ -163,7 +163,7 @@ void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
int nFrameSizeTop = geo.y() - frameGeo.y();
int nFrameSizeLeft = geo.x() - frameGeo.x();
- // create the new tqgeometry that is accepted by the TQWidget::setGeometry() method
+ // create the new geometry that is accepted by the TQWidget::setGeometry() method
TQRect newGeoTQt;
newGeoTQt.setX( newGeometry.x() - nFrameSizeLeft );
@@ -172,19 +172,19 @@ void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
newGeoTQt.setWidth( newGeometry.width() );
newGeoTQt.setHeight( newGeometry.height() );
- // set the tqgeometry
+ // set the geometry
setGeometry( newGeoTQt );
}
}
-//============== external tqgeometry ==============//
+//============== external geometry ==============//
TQRect KMdiChildView::externalGeometry() const
{
return mdiParent() ? mdiParent()->frameGeometry() : frameGeometry();
}
//============== set external tqgeometry ==============//
void KMdiChildView::setExternalGeometry( const TQRect& newGeometry )
{
@@ -202,7 +202,7 @@ void KMdiChildView::setExternalGeometry( const TQRect& newGeometry )
int nFrameSizeTop = geo.y() - frameGeo.y();
int nFrameSizeLeft = geo.x() - frameGeo.x();
- // create the new tqgeometry that is accepted by the TQWidget::setGeometry() method
+ // create the new geometry that is accepted by the TQWidget::setGeometry() method
// not attached => the window system makes the frame
TQRect newGeoTQt;
newGeoTQt.setX( newGeometry.x() + nFrameSizeLeft );
@@ -210,7 +210,7 @@ void KMdiChildView::setExternalGeometry( const TQRect& newGeometry )
newGeoTQt.setWidth( newGeometry.width() - nTotalFrameWidth );
newGeoTQt.setHeight( newGeometry.height() - nTotalFrameHeight );
- // set the tqgeometry
+ // set the geometry
setGeometry( newGeoTQt );
}
}
@@ -277,7 +277,7 @@ TQRect KMdiChildView::restoreGeometry()
if ( mdiParent() )
return mdiParent() ->restoreGeometry();
else //FIXME not really supported, may be we must use Windows or X11 funtions
- return tqgeometry();
+ return geometry();
}
//============== setRestoreGeometry ================//
@@ -491,7 +491,7 @@ void KMdiChildView::slot_childDestroyed()
// do what we do if a child is removed
// if we lost a child we uninstall ourself as event filter for the lost
- // child and its tqchildren
+ // child and its children
const TQObject * pLostChild = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(TQT_BASE_OBJECT_NAME::sender()));
if ( pLostChild && ( pLostChild->isWidgetType() ) )
{
@@ -564,7 +564,7 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
else if ( e->type() == TQEvent::ChildRemoved )
{
// if we lost a child we uninstall ourself as event filter for the lost
- // child and its tqchildren
+ // child and its children
TQObject * pLostChild = TQT_TQOBJECT(( ( TQChildEvent* ) e ) ->child());
if ( ( pLostChild != 0L ) && ( pLostChild->isWidgetType() ) )
{
@@ -593,7 +593,7 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
else if ( e->type() == TQEvent::ChildInserted )
{
// if we got a new child and we are attached to the MDI system we
- // install ourself as event filter for the new child and its tqchildren
+ // install ourself as event filter for the new child and its children
// (as we did when we were added to the MDI system).
TQObject * pNewChild = TQT_TQOBJECT(( ( TQChildEvent* ) e ) ->child());
if ( ( pNewChild != 0L ) && ( pNewChild->isWidgetType() ) )
@@ -123,14 +123,14 @@ TQRect KMdiChildView::internalGeometry() const
}
}
-//============== set internal tqgeometry ==============//
+//============== set internal geometry ==============//
void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
{
@@ -172,19 +172,19 @@ void KMdiChildView::setInternalGeometry( const TQRect& newGeometry )
return mdiParent() ? mdiParent()->frameGeometry() : frameGeometry();
}
-//============== set external tqgeometry ==============//
+//============== set external geometry ==============//
void KMdiChildView::setExternalGeometry( const TQRect& newGeometry )
{
diff --git a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
index cf2fa780..0c577360 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
@@ -298,14 +298,14 @@ void KMdiMainFrm::setStandardMDIMenuEnabled( bool showModeMenu )
//============ ~KMdiMainFrm ============//
KMdiMainFrm::~KMdiMainFrm()
{
- //save the tqchildren first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView*> tqchildren;
+ //save the children first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView*> children;
for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
- tqchildren.append( w );
+ children.append( w );
// safely close the windows so properties are saved...
TQValueListIterator<KMdiChildView*> childIt;
- for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
+ for ( childIt = children.begin(); childIt != children.end(); ++childIt )
{
closeWindow( *childIt, false ); // without re-tqlayout taskbar!
}
@@ -586,7 +586,7 @@ KMdiToolViewAccessor *KMdiMainFrm::addToolWindow( TQWidget* pWnd, KDockWidget::D
pWnd = pDW;
}
- TQRect r = pWnd->tqgeometry();
+ TQRect r = pWnd->geometry();
KMdiToolViewAccessor *mtva = new KMdiToolViewAccessor( this, pWnd, tabToolTip, ( tabCaption == 0 ) ? pWnd->caption() : tabCaption );
m_pToolViews->insert( tvta, mtva );
@@ -614,7 +614,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
TQRect frameGeo = pWnd->frameGeometry();
TQPoint topLeftScreen = pWnd->mapToGlobal( TQPoint( 0, 0 ) );
TQPoint topLeftMdiChildArea = m_pMdi->mapFromGlobal( topLeftScreen );
- TQRect childAreaGeo = m_pMdi->tqgeometry();
+ TQRect childAreaGeo = m_pMdi->geometry();
if ( topLeftMdiChildArea.x() < 0 || topLeftMdiChildArea.y() < 0 ||
( topLeftMdiChildArea.x() + frameGeo.width() > childAreaGeo.width() ) ||
( topLeftMdiChildArea.y() + frameGeo.height() > childAreaGeo.height() ) )
@@ -643,7 +643,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
m_pMdi->manageChild( lpC, false, bCascade );
if ( m_pMdi->topChild() && m_pMdi->topChild() ->isMaximized() )
{
- TQRect r = lpC->tqgeometry();
+ TQRect r = lpC->geometry();
lpC->setGeometry( -lpC->m_pClient->x(), -lpC->m_pClient->y(),
m_pMdi->width() + KMDI_CHILDFRM_DOUBLE_BORDER,
m_pMdi->height() + lpC->captionHeight() + KMDI_CHILDFRM_SEPARATOR + KMDI_CHILDFRM_DOUBLE_BORDER );
@@ -1238,14 +1238,14 @@ bool KMdiMainFrm::eventFilter( TQObject * /*obj*/, TQEvent *e )
*/
void KMdiMainFrm::closeAllViews()
{
- //save the tqchildren first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView*> tqchildren;
+ //save the children first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView*> children;
for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
{
- tqchildren.append( w );
+ children.append( w );
}
TQValueListIterator<KMdiChildView *> childIt;
- for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
+ for ( childIt = children.begin(); childIt != children.end(); ++childIt )
{
( *childIt )->close();
}
@@ -1273,7 +1273,7 @@ void KMdiMainFrm::closeActiveView()
m_pCurrentWindow->close();
}
/** find the root dockwidgets and store their tqgeometry */
void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetList, TQValueList<TQRect>* positionList )
{
//nothing is valid
@@ -1289,7 +1289,7 @@ void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetLis
pObjList = queryList( "KDockWidget_Compat::KDockWidget" );
TQObjectListIt it( *pObjList );
// for all dockwidgets (which are tqchildren of this mainwindow)
while ( ( *it ) )
{
KDockWidget* dockWindow = 0L; /* pDockW */
@@ -1357,7 +1357,7 @@ void KMdiMainFrm::switchToToplevelMode()
const int frameBorderWidth = 7; // @todo: Can we / do we need to ask the window manager?
setUndockPositioningOffset( TQPoint( 0, ( m_pTaskBar ? m_pTaskBar->height() : 0 ) + frameBorderWidth ) );
// 1.) select the dockwidgets to be undocked and store their tqgeometry
TQPtrList<KDockWidget> rootDockWidgetList;
TQValueList<TQRect> positionList;
@@ -1470,7 +1470,7 @@ void KMdiMainFrm::switchToChildframeMode()
if ( m_mdiMode == KMdi::TabPageMode )
{
kdDebug(760) << k_funcinfo << "finishing tab page mode" << endl;
// select the dockwidgets to be undocked and store their tqgeometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1490,7 +1490,7 @@ void KMdiMainFrm::switchToChildframeMode()
kdDebug(760) << k_funcinfo << "finishing ideal mode" << endl;
finishIDEAlMode( false );
// select the dockwidgets to be undocked and store their tqgeometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1273,7 +1273,7 @@ void KMdiMainFrm::closeActiveView()
m_pCurrentWindow->close();
}
-/** find the root dockwidgets and store their tqgeometry */
+/** find the root dockwidgets and store their geometry */
void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetList, TQValueList<TQRect>* positionList )
{
@@ -1289,7 +1289,7 @@ void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetLis
pObjList = queryList( "KDockWidget_Compat::KDockWidget" );
TQObjectListIt it( *pObjList );
- // for all dockwidgets (which are tqchildren of this mainwindow)
+ // for all dockwidgets (which are children of this mainwindow)
while ( ( *it ) )
{
@@ -1357,7 +1357,7 @@ void KMdiMainFrm::switchToToplevelMode()
const int frameBorderWidth = 7; // @todo: Can we / do we need to ask the window manager?
setUndockPositioningOffset( TQPoint( 0, ( m_pTaskBar ? m_pTaskBar->height() : 0 ) + frameBorderWidth ) );
- // 1.) select the dockwidgets to be undocked and store their tqgeometry
+ // 1.) select the dockwidgets to be undocked and store their geometry
TQPtrList<KDockWidget> rootDockWidgetList;
TQValueList<TQRect> positionList;
@@ -1470,7 +1470,7 @@ void KMdiMainFrm::switchToChildframeMode()
{
kdDebug(760) << k_funcinfo << "finishing tab page mode" << endl;
- // select the dockwidgets to be undocked and store their tqgeometry
+ // select the dockwidgets to be undocked and store their geometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1490,7 +1490,7 @@ void KMdiMainFrm::switchToChildframeMode()
kdDebug(760) << k_funcinfo << "finishing ideal mode" << endl;
finishIDEAlMode( false );
- // select the dockwidgets to be undocked and store their tqgeometry
+ // select the dockwidgets to be undocked and store their geometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;